@@ -26,7 +26,7 @@ def change_manifest():
     sed_command_manifest = "sed -i 's/version: {}/version: {}/g' ./manifest.yml".format(version.rstrip(), new_version)
  
     ## update version number in manifest.yml
-    process_sed_manifest = __main__.subprocess.Popen(sed_command_manifest, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+    process_sed_manifest = __main__.Popen(sed_command_manifest, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
 
 def modify_version():
     if __main__.arch_type == 'npm':
@@ -42,7 +42,7 @@ def modify_version():
         print("Working directory: ",path)
         ##version = subprocess.run(["node -p \"require('./package.json').version\""], stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=path)
         ##version = subprocess.run(["echo 1.0.1"], stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=path)
-        process_result = __main__.subprocess.Popen("node -p \"require('./package.json').version\"", shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+        process_result = __main__.Popen("node -p \"require('./package.json').version\"", shell=True, stdout=__main__.PIPE, cwd=path)
         version_result = process_result.communicate()[0]
         version = str(version_result, 'utf-8')
         version_lst = version.rstrip().split(".")
@@ -82,14 +82,14 @@ def modify_version():
             
         
         git_checkout_command = "git checkout -b feature/modify-version"
-        process_git_checkout = __main__.subprocess.Popen(git_checkout_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+        process_git_checkout = __main__.Popen(git_checkout_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
         print("Checkout result: ", process_git_checkout.communicate()[0])
         
         ## update version number in package.json
         sed_command = "sed -i 's/\"version\": \"{}\"/\"version\": \"{}\"/g' ./package.json".format(version.rstrip(), new_version)
         ## print('SED command: ', sed_command)
         
-        process_sed = __main__.subprocess.Popen(sed_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+        process_sed = __main__.Popen(sed_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
         
         change_manifest()  ## Update manifest file
     
@@ -103,7 +103,7 @@ def modify_version():
         ## update version number in package.json
         sed_buildgradle_command = "sed -i 's/\"version\": \"{}\"/\"version\": \"{}\"/g' ./build.gradle".format(version.rstrip(), new_version)
         ## print('SED command: ', sed_command)
-        process_sed = __main__.subprocess.Popen(sed_buildgradle_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
+        process_sed = __main__.Popen(sed_buildgradle_command, shell=True, stdout=__main__.subprocess.PIPE, cwd=path)
         
         return sys.exit(0)
     elif __main__.arch_type == 'dotnet':
